#import libraries
from ase.io import read
from ase.calculators.vasp import Vasp
import os
import subprocess
from datetime import datetime

startTime = datetime.now()

#Set up parameters
atobj=read('POSCAR') #read atoms object
System=atobj.copy() #make copy of atoms object
vasp_settings = {'xc': 'PBE',        #Functional to use
                 'pp': 'PBE',         #Pseudopotential used
                 'reciprocal':False, #Projection operators evaluated in real space if False
                 'gga': 'PE',        #Type of GGA: PBE
                 'kpts': (3,2,1),    #K point mesh
				 'gamma':True,       # Gamma true
                 'setups': {'Ti': '_sv'}} #orbitals to include for Zr    

#Initalize 1st Calculation
calc = Vasp(**vasp_settings) #Create a VASP calculator object
calc.initialize(System)
calc.write_kpoints() #Generate a VASP KPOINTS file
calc.write_potcar() #Generate a VASP POTCAR file
print('1st NEB calculation underway\n')
calc.run()

#Print Result
print('Calculation complete \n')
total_runtime = ((datetime.now() - startTime).total_seconds())/3600
print('Total Runtime (hours): %.2f' % total_runtime)
                                                    